@@ -441,7 +441,7 @@ def ProcessBatch(sourcefolder, outputfolder,
                                          array_dimensions = array_dimensions, pin_size = pin_size,
                                          features = features, adjust = adjust, rotate = rotate, 
                                          save = False, display = False, calibrate = calibrate)
-        user_input == 'y'
+        user_input = 'y'
         
     # -- Process all images
     if user_input == 'y':
@@ -693,7 +693,7 @@ def ParallelProcessBatch(sourcefolder, outputfolder, numThreads = 2,
                                          array_dimensions = array_dimensions, pin_size = pin_size,
                                          features = features, adjust = adjust, rotate = rotate, 
                                          save = False, display = False, calibrate = calibrate)
-        user_input == 'y'
+        user_input = 'y'
         
     # -- Process all images
     if user_input == 'y':
